Pyorbital
=========

[![Build status](https://github.com/pytroll/pyorbital/workflows/CI/badge.svg?branch=main)](https://github.com/pytroll/pyorbital/workflows/CI/badge.svg?branch=main)
[![Coverage Status](https://coveralls.io/repos/github/pytroll/pyorbital/badge.svg?branch=main)](https://coveralls.io/github/pytroll/pyorbital?branch=main)
[![PyPI version](https://badge.fury.io/py/pyorbital.svg)](https://badge.fury.io/py/pyorbital)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6078954.svg)](https://doi.org/10.5281/zenodo.6078954)



This is the Pyorbital, a Python package for computing orbital parameters from TLE
files, and making various astronomical computations.

It is part of the Pytroll project: http://pytroll.org

